==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/template/am_default/g_files_edit.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<form action="g_files_edit.php" method="post" enctype="multipart/form-data">
<input type="hidden" name="group_id" value="<?php echo $group['group_id'];?>" />
<?php 
$max_allocation = $storage['allocation'] - $storage['allocation_used'];
?>
<input type="hidden" name="MAX_FILE_SIZE" value="<?php echo $max_allocation;?>" />
				
<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "g_menu.inc.tpl.php";
			?>
			
			<?php
			if (isset($storage['allocation'])) {
			
			$percentage_used = floor((100/$storage['allocation']) * $storage['allocation_used']);
			if ($percentage_used > 100) {
			    $percentage_used = 100;
			}
			$percentage_unused = 100 - $percentage_used;
			
			if ($storage['allocation'] > $storage['allocation_used']) {
			
			?>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			
			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr>
					<td class="txt_title">
						<?php echo $lang['section_action'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<a href="g_files_edit.php?add_image=1&amp;group_id=<?php echo $group['group_id'];?>" class="txt_sub_menu"><?php echo $lang['href_file_add'];?></a><br />
					</td>
				</tr>
			</table>
			<?php }}?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="560" valign="top">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="2" class="txt_title" align="right">
						<?php echo $lang['hdr_storage'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td width="50%" valign="top">
						<?php echo $lang['txt_storage_allowed'];?>: <?php echo round($storage['allocation']/1000); ?>kb<br />
						<?php echo $lang['txt_storage_total'];?>: <?php echo round($storage['allocation_used']/1000, 2); ?>kb<br />
					</td>
					<td width="50%" valign="top">
						<?php
						if (isset($storage['allocation'])) {
						?>
						<table border="0" cellspacing="0" cellpadding="0" width="100%">
							<tr>
								<td width="<?php echo $percentage_used;?>%" class="bg1">
									<img src=<?php echo $templatePath;?>img/pixel.png width="1" height="7" alt="" /><br />
								</td>
								<td width="<?php echo $percentage_unused;?>%" class="bg2">
									<img src=<?php echo $templatePath;?>img/pixel.png width="1" height="7" alt="" /><br />
								</td>
							</tr>
						</table>
						<p align="right">
						<?php
						if ($storage['allocation'] <= $storage['allocation_used']) {
							echo $lang['txt_storage_no_add'];
						}
					}
					?>
					</p>
					</td>
				</tr>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<?php
			if (isset($display) && $display == "add") {
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_add_file'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<table border="0" cellspacing="0" cellpadding="4">
							<tr>
								<td valign="top" colspan="2">
									<?php echo $lang['txt_intro'];?><br />
								</td>
							</tr>
							<tr>
								<td valign="top" colspan="2">
									<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
								</td>
							</tr>
							<tr>
								<td valign="top" colspan="2">
									<b><?php echo $lang['txt_file_title'];?></b><br />
								</td>
							</tr>
							<tr>
								<td valign="top" colspan="2">
									<input name="data[file_title]" type="text" size="33" value="" class="formInput"><br />
								</td>
							</tr>
							<tr>
								<td valign="top" colspan="2">
									<span class="txt_footer"><?php echo $lang['txt_add_file'];?></span><br />
								</td>
							</tr>
							<tr>
								<td valign="top" colspan="2">
									<input type="file" name="upload_file" size="33" class="formInput"><br />
								</td>
							</tr>
							<tr>
								<td colspan="2" align="right">
									<INPUT type="submit" name="insert_file" value="<?php echo $lang['sub_upload'];?>" class="formInput"><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<?php
			}
			else if (isset($display) && $display == "edit") {
			?>
			<input type="hidden" name="data[file_id]" value="<?php echo $out_file['file_id'];?>" />
			<input type="hidden" name="data[file_name]" value="<?php echo $out_file['file_name'];?>" />
			<input type="hidden" name="data[file_suffix]" value="<?php echo $out_file['file_suffix'];?>" />
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="2" class="txt_title" align="right">
						<?php echo $lang['hdr_files'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td valign="top">
						<?php echo $lang['txt_file_id'];?>: <?php echo $out_file['file_id'];?><br />
					</td>
					<td valign="top" align="right">
						<a href="g_files_edit.php?group_id=<?php echo $group['group_id'];?>"><?php echo $lang['href_list'];?></a><br />
					</td>
				</tr>
				<tr>
					<td colspan="2">
						<?php formatFileOutput($out_file);?><br />
					</td>
				</tr>
				<tr>
						<td valign="top" colspan="2">
							<b><?php echo $lang['txt_file_title'];?></b><br />
						</td>
					</tr>
					<tr>
						<td valign="top" colspan="2">
							<input name="data[file_title]" type="text" size="33" value="<?php echo $out_file['file_title'];?>" class="formInput"><br />
						</td>
					</tr>
				<tr>
					<td valign="top" colspan="2">
						<span class="txt_footer"><?php echo $lang['txt_edit_file'];?></span><br />
					</td>
				</tr>
				<tr>
					<td valign="top" colspan="2">
						(<?php echo $out_file['file_name'] . "." . $out_file['file_suffix'];?>)<br />
						<input type="file" name="upload_file" size="33" class="formInput" /><br />
					</td>
				</tr>
				<tr>
					<td valign="top" colspan="2">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
					</td>
				</tr>
				<tr>
					<td valign="top">
						<input type="submit" name="delete_file" value="<?php echo $lang['sub_delete'];?>" class="formInput" /><br />
					</td>
					<td align="right" valign="top">
						<input type="submit" name="update_file" value="<?php echo $lang['sub_update'];?>" class="formInput" /><br />
					</td>
				</tr>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
					
			<?php
			}
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="6" class="txt_title" align="right">
						<?php echo $lang['hdr_files'];?><br />
						<hr />
					</td>
				</tr>
				<tr class="bg_2">
					<td valign="top" width="1%">
						&nbsp;<br />
					</td>
					<td valign = "top">
						<?php echo $lang['txt_file_title'];?><br />
					</td>
					<td valign = "top">
						<?php echo $lang['txt_file_id'];?><br />
					</td>
					<td valign = "top">
						<?php echo $lang['txt_file_name'];?><br />
					</td>
					<td valign = "top" align="right">
						<?php echo $lang['txt_file_size'];?><br />
					</td>
					<td valign = "top" align="right">
						<?php echo $lang['txt_default_image'];?><br />
					</td>
				</tr>
				<?php
				if (isset($files)) {
				foreach($files as $i): ?>
				<tr>
					<td valign="top" width="1%">
						<a href="g_files_edit.php?file_id=<?php echo $i['file_id'];?>&amp;group_id=<?php echo $group['group_id'];?>"><?php formatFileOutput($i, "thumb");?></a><br />
					</td>
					<td valign = "top">
						<a href="g_files_edit.php?file_id=<?php echo $i['file_id'];?>&amp;group_id=<?php echo $group['group_id'];?>"><?php echo $i['file_title'];?></a><br />
					</td>
					<td valign = "top">
						<?php echo $i['file_id'];?><br />
					</td>
					<td valign = "top">
						<?php echo $i['file_name'];?>.<?php echo $i['file_suffix'];?><br />
					</td>
					<td valign = "top" align="right">
						<?php echo round($i['file_size']/1000, 2);?>kb<br />
					</td>
					<td valign = "top" align="right">
						<?php
						if ($i['file_suffix'] == "jpg" || $i['file_suffix'] == "gif" || $i['file_suffix'] == "png") {
						
						$selected = "";
						if (isset($group['file_id']) && $group['file_id'] == $i['file_id']) {
						    $selected = "checked=\"checked\"";
						}
						?>
						<input type="radio" name="data[default_file_id]" value="<?php echo $i['file_id'];?>" <?php echo $selected;?> />
						<?php }?><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>

				<?php
				}
				?>
				<tr>
					<td align="right" colspan="6">
						<input type="submit" name="set_default" value="<?php echo $lang['sub_update_default_image'];?>" class="formInput" /><br />
					</td>
				</tr>
			</table>
		</td>
	</tr>
</table>
</form>

==> aroundme_0_4_3.zip: aroundme_0_4_3/www/aroundme_0_4_3/template/am_default/g_files_edit.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<form action="g_files_edit.php" method="post" enctype="multipart/form-data">
<input type="hidden" name="group_id" value="<?php echo $group['group_id'];?>" />
<?php 
$max_allocation = $storage['allocation'] - $storage['allocation_used'];
?>
<input type="hidden" name="MAX_FILE_SIZE" value="<?php echo $max_allocation;?>" />
				
<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "g_menu.inc.tpl.php";
			?>
			
			<?php
			if (isset($storage['allocation'])) {
			
			$percentage_used = floor((100/$storage['allocation']) * $storage['allocation_used']);
			if ($percentage_used > 100) {
			    $percentage_used = 100;
			}
			$percentage_unused = 100 - $percentage_used;
			
			if ($storage['allocation'] > $storage['allocation_used']) {
			
			?>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			
			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr>
					<td class="txt_title">
						<?php echo $lang['section_action'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<a href="g_files_edit.php?add_image=1&amp;group_id=<?php echo $group['group_id'];?>" class="txt_sub_menu"><?php echo $lang['href_file_add'];?></a><br />
					</td>
				</tr>
			</table>
			<?php }}?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="560" valign="top">
			<table width="100%" cellpadding="4" cellspacing="0" border="0" class="table_stnd">
				<tr>
					<td colspan="2" class="txt_title" align="right">
						<?php echo $lang['hdr_storage'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td width="50%" valign="top">
						<?php echo $lang['txt_storage_allowed'];?>: <?php echo round($storage['allocation']/1000); ?>kb<br />
						<?php echo $lang['txt_storage_total'];?>: <?php echo round($storage['allocation_used']/1000, 2); ?>kb<br />
					</td>
					<td width="50%" valign="top">
						<?php
						if (isset($storage['allocation'])) {
						?>
						<table border="0" cellspacing="0" cellpadding="0" width="100%" class="table_nested">
							<tr>
								<td width="<?php echo $percentage_used;?>%" class="bg1">
									<img src=<?php echo $templatePath;?>img/pixel.png width="1" height="7" alt="" /><br />
								</td>
								<td width="<?php echo $percentage_unused;?>%" class="bg2">
									<img src=<?php echo $templatePath;?>img/pixel.png width="1" height="7" alt="" /><br />
								</td>
							</tr>
						</table>
						<p align="right">
						<?php
						if ($storage['allocation'] <= $storage['allocation_used']) {
							echo $lang['txt_storage_no_add'];
						}
					}
					?>
					</p>
					</td>
				</tr>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<?php
			if (isset($display) && $display == "add") {
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0" class="table_stnd">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_add_file'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<table border="0" cellspacing="0" cellpadding="4" class="table_nested">
							<tr>
								<td valign="top" colspan="2">
									<?php echo $lang['txt_intro'];?><br />
								</td>
							</tr>
							<tr>
								<td valign="top" colspan="2">
									<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
								</td>
							</tr>
							<tr>
								<td valign="top" colspan="2">
									<b><?php echo $lang['txt_file_title'];?></b><br />
								</td>
							</tr>
							<tr>
								<td valign="top" colspan="2">
									<input name="data[file_title]" type="text" size="33" value="" class="formInput"><br />
								</td>
							</tr>
							<tr>
								<td valign="top" colspan="2">
									<span class="txt_footer"><?php echo $lang['txt_add_file'];?></span><br />
								</td>
							</tr>
							<tr>
								<td valign="top" colspan="2">
									<input type="file" name="upload_file" size="33" class="formInput"><br />
								</td>
							</tr>
							<tr>
								<td colspan="2" align="right">
									<INPUT type="submit" name="insert_file" value="<?php echo $lang['sub_upload'];?>" class="formInput"><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<?php
			}
			else if (isset($display) && $display == "edit") {
			?>
			<input type="hidden" name="data[file_id]" value="<?php echo $out_file['file_id'];?>" />
			<input type="hidden" name="data[file_name]" value="<?php echo $out_file['file_name'];?>" />
			<input type="hidden" name="data[file_suffix]" value="<?php echo $out_file['file_suffix'];?>" />
			<table width="100%" cellpadding="4" cellspacing="0" border="0" class="table_stnd">
				<tr>
					<td colspan="2" class="txt_title" align="right">
						<?php echo $lang['hdr_files'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td valign="top">
						<?php echo $lang['txt_file_id'];?>: <?php echo $out_file['file_id'];?><br />
					</td>
					<td valign="top" align="right">
						<a href="g_files_edit.php?group_id=<?php echo $group['group_id'];?>"><?php echo $lang['href_list'];?></a><br />
					</td>
				</tr>
				<tr>
					<td colspan="2">
						<?php formatFileOutput($out_file);?><br />
					</td>
				</tr>
				<tr>
						<td valign="top" colspan="2">
							<b><?php echo $lang['txt_file_title'];?></b><br />
						</td>
					</tr>
					<tr>
						<td valign="top" colspan="2">
							<input name="data[file_title]" type="text" size="33" value="<?php echo $out_file['file_title'];?>" class="formInput"><br />
						</td>
					</tr>
				<tr>
					<td valign="top" colspan="2">
						<span class="txt_footer"><?php echo $lang['txt_edit_file'];?></span><br />
					</td>
				</tr>
				<tr>
					<td valign="top" colspan="2">
						(<?php echo $out_file['file_name'] . "." . $out_file['file_suffix'];?>)<br />
						<input type="file" name="upload_file" size="33" class="formInput" /><br />
					</td>
				</tr>
				<tr>
					<td valign="top" colspan="2">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
					</td>
				</tr>
				<tr>
					<td valign="top">
						<input type="submit" name="delete_file" value="<?php echo $lang['sub_delete'];?>" class="formInput" /><br />
					</td>
					<td align="right" valign="top">
						<input type="submit" name="update_file" value="<?php echo $lang['sub_update'];?>" class="formInput" /><br />
					</td>
				</tr>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
					
			<?php
			}
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0" class="table_stnd">
				<tr>
					<td colspan="6" class="txt_title" align="right">
						<?php echo $lang['hdr_files'];?><br />
						<hr />
					</td>
				</tr>
				<tr class="bg_2">
					<td valign="top" width="1%">
						&nbsp;<br />
					</td>
					<td valign = "top">
						<?php echo $lang['txt_file_title'];?><br />
					</td>
					<td valign = "top">
						<?php echo $lang['txt_file_id'];?><br />
					</td>
					<td valign = "top">
						<?php echo $lang['txt_file_name'];?><br />
					</td>
					<td valign = "top" align="right">
						<?php echo $lang['txt_file_size'];?><br />
					</td>
					<td valign = "top" align="right">
						<?php echo $lang['txt_default_image'];?><br />
					</td>
				</tr>
				<?php
				if (isset($files)) {
				foreach($files as $i): ?>
				<tr>
					<td valign="top" width="1%">
						<a href="g_files_edit.php?file_id=<?php echo $i['file_id'];?>&amp;group_id=<?php echo $group['group_id'];?>"><?php formatFileOutput($i, "thumb");?></a><br />
					</td>
					<td valign = "top">
						<a href="g_files_edit.php?file_id=<?php echo $i['file_id'];?>&amp;group_id=<?php echo $group['group_id'];?>"><?php echo $i['file_title'];?></a><br />
					</td>
					<td valign = "top">
						<?php echo $i['file_id'];?><br />
					</td>
					<td valign = "top">
						<?php echo $i['file_name'];?>.<?php echo $i['file_suffix'];?><br />
					</td>
					<td valign = "top" align="right">
						<?php echo round($i['file_size']/1000, 2);?>kb<br />
					</td>
					<td valign = "top" align="right">
						<?php
						if ($i['file_suffix'] == "jpg" || $i['file_suffix'] == "gif" || $i['file_suffix'] == "png") {
						
						$selected = "";
						if (isset($group['file_id']) && $group['file_id'] == $i['file_id']) {
						    $selected = "checked=\"checked\"";
						}
						?>
						<input type="radio" name="data[default_file_id]" value="<?php echo $i['file_id'];?>" <?php echo $selected;?> />
						<?php }?><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>

				<?php
				}
				?>
				<tr>
					<td align="right" colspan="6">
						<input type="submit" name="set_default" value="<?php echo $lang['sub_update_default_image'];?>" class="formInput" /><br />
					</td>
				</tr>
			</table>
		</td>
	</tr>
</table>
</form>
